@@ -16,11 +16,14 @@ import logging
 
 from pyrenoweb.const import (
     BASE_URL,
+    DA_WEEKDAYS_LONG,
+    DA_WEEKDAYS_SHORT,
     DAWA_URL,
     DEFAULT_TIMEOUT,
     NO_WASTE_SCHEDULE_TIMESTAMP,
     WASTE_LIST,
 )
+from pyrenoweb.data import RenowWebDataItem
 from pyrenoweb.errors import (
     InvalidApiKey,
     RequestError,
@@ -256,74 +259,87 @@ class RenoWebData:
         endpoint = f"GetJSONContainerList.aspx?municipalitycode={self._municipality_id}&apikey={self._api_key}&adressId={self._address_id}&fullinfo=1&supportsSharedEquipment=1"
         json_data = await self.async_request("get", endpoint)
         next_days_to = 10000
-        entries = {}
+        data_set = []
         if json_data["list"] is not None:
             for row in json_data["list"]:
                 module = row.get("module")
                 fraction_name = module.get("fractionname").replace("/", "_")
                 fraction_id = row.get("id")
                 if row.get("nextpickupdatetimestamp").isnumeric():
-                    next_pickup = datetime.datetime.utcfromtimestamp(int(row.get("nextpickupdatetimestamp")))
+                    next_pickup = datetime.date.fromtimestamp(int(row.get("nextpickupdatetimestamp")))
                     valid_data = True
                 else:
                     # There is currently no data for the Waste Type, so set a future date
-                    next_pickup = datetime.datetime.utcfromtimestamp(NO_WASTE_SCHEDULE_TIMESTAMP)
+                    next_pickup = datetime.date.fromtimestamp(NO_WASTE_SCHEDULE_TIMESTAMP)
                     valid_data = False
 
+                # Format and create attributes
                 name = row["name"]
                 schedule = row.get("pickupdates")
                 icon_list = list(filter(lambda WASTE_LIST: WASTE_LIST['type'] == fraction_name, WASTE_LIST))
-                days_to = (next_pickup - datetime.datetime.now()).days
+                days_to = (next_pickup - datetime.date.today()).days 
+                next_pickup_long = DA_WEEKDAYS_LONG[int(next_pickup.strftime("%w"))] + next_pickup.strftime(" d. %d-%m-%Y")
+                next_pickup_short = DA_WEEKDAYS_SHORT[int(next_pickup.strftime("%w"))] + next_pickup.strftime(" d. %d-%m")
                 if days_to == 0:
                     icon_color = "#F54336"
+                    template_text = "I dag"
                 elif days_to == 1:
                     icon_color = "#FFC108"
+                    template_text = "I morgen"
                 else:
                     icon_color = "#9E9E9E"
+                    template_text = f"Om {days_to} dage"
 
                 # Build Data for the Next Collection Sensor
                 if days_to < next_days_to:
                     next_date = next_pickup
+                    next_date_long = next_pickup_long
+                    next_date_short = next_pickup_short
                     next_icon = icon_list[0]['icon']
+                    next_template_text = template_text
                     next_valid_data = valid_data
                     next_schedule = schedule
                     next_days_to = days_to
                     next_icon_color = icon_color
                     next_id = fraction_id
 
-                sensor_item = {
-                    f"{fraction_name}_{self._municipality_id}_{self._address_id}": {
-                        "key": f"{fraction_name}",
-                        "date": next_pickup,
-                        "icon": icon_list[0]['icon'],
-                        "valid_data": valid_data,
-                        "name": name,
-                        "schedule": schedule,
-                        "days_to": days_to,
-                        "icon_color": icon_color,
-                        "id": fraction_id,
-                    }
-                } 
-                entries.update(sensor_item)
+                data_item = RenowWebDataItem(
+                    key=f"{fraction_name}",
+                    date=next_pickup,
+                    date_long=next_pickup_long,
+                    date_short=next_pickup_short,
+                    icon=icon_list[0]['icon'],
+                    icon_color=icon_color,
+                    valid_data=valid_data,
+                    name=name,
+                    schedule=schedule,
+                    days_to=days_to,
+                    state_text=template_text,
+                    fraction_id=fraction_id,
+                    last_refresh=datetime.datetime.now(),
+                )
+                data_set.append(data_item)
 
         # Add a Status Sensor
-        sensor_item = {
-            f"Next Collection_{self._municipality_id}_{self._address_id}": {
-                "key": "Next Collection",
-                "date": next_date,
-                "icon": next_icon,
-                "valid_data": next_valid_data,
-                "name": "Næste tømning",
-                "schedule": next_schedule,
-                "days_to": next_days_to,
-                "icon_color": next_icon_color,
-                "id": next_id,
-            }
-        } 
-        entries.update(sensor_item)
+        data_item = RenowWebDataItem(
+            key="Next Collection",
+            date=next_date,
+            date_long=next_date_long,
+            date_short=next_date_short,
+            icon=next_icon,
+            icon_color=next_icon_color,
+            valid_data=next_valid_data,
+            name="Næste tømning",
+            schedule=next_schedule,
+            days_to=next_days_to,
+            state_text=next_template_text,
+            fraction_id=next_id,
+            last_refresh=datetime.datetime.now(),
+        )
+        data_set.append(data_item)
 
-
-        return entries
+        return data_set
+        # return entries
 
     async def get_raw_pickup_data(self) -> None:
         """Return raw json data array with pick up data for the address."""
